Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(267)

Unified Diff: net/dns/serial_worker.h

Issue 1137433003: Encouraging ThreadTaskRunnerHandle usage in net/dns module (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed build failure Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/dns/host_resolver_impl.cc ('k') | net/dns/serial_worker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/dns/serial_worker.h
diff --git a/net/dns/serial_worker.h b/net/dns/serial_worker.h
index 59a4d3f189ca1c8e2f2bb0b7ea6356aa36a21f32..f63178a593ed91c41b556dc516fadc2d11ae7c51 100644
--- a/net/dns/serial_worker.h
+++ b/net/dns/serial_worker.h
@@ -13,7 +13,7 @@
// Forward declaration
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
}
namespace net {
@@ -61,7 +61,7 @@ class NET_EXPORT_PRIVATE SerialWorker
// Executed on origin thread after |DoRead| completes.
virtual void OnWorkFinished() = 0;
- base::MessageLoopProxy* loop() { return message_loop_.get(); }
+ base::SingleThreadTaskRunner* loop() { return task_runner_.get(); }
private:
enum State {
@@ -82,8 +82,8 @@ class NET_EXPORT_PRIVATE SerialWorker
// Posted to message loop in case WorkerPool is busy. (state == WAITING)
void RetryWork();
- // Message loop for the thread of origin.
- scoped_refptr<base::MessageLoopProxy> message_loop_;
+ // Task runner for the thread of origin.
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
State state_;
« no previous file with comments | « net/dns/host_resolver_impl.cc ('k') | net/dns/serial_worker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698